@@ -1,19 +1,18 @@
-from __future__ import with_statement
-
+from __future__ import print_function
 import sys
-import os
 import optparse
 import cProfile
 import inspect
+import pkg_resources
 
 import scrapy
 from scrapy.crawler import CrawlerProcess
 from scrapy.xlib import lsprofcalltree
-from scrapy.conf import settings
 from scrapy.command import ScrapyCommand
-from scrapy.exceptions import UsageError, ScrapyDeprecationWarning
+from scrapy.exceptions import UsageError
 from scrapy.utils.misc import walk_modules
-from scrapy.utils.project import inside_project
+from scrapy.utils.project import inside_project, get_project_settings
+from scrapy.settings.deprecated import check_deprecated_settings
 
 def _iter_command_classes(module_name):
     # TODO: add `name` attribute to commands and and merge this function with
@@ -33,8 +32,19 @@ def _get_commands_from_module(module, inproject):
             d[cmdname] = cmd()
     return d
 
-def _get_commands_dict(inproject):
+def _get_commands_from_entry_points(inproject, group='scrapy.commands'):
+    cmds = {}
+    for entry_point in pkg_resources.iter_entry_points(group):
+        obj = entry_point.load()
+        if inspect.isclass(obj):
+            cmds[entry_point.name] = obj()
+        else:
+            raise Exception("Invalid entry point %s" % entry_point.name)
+    return cmds
+
+def _get_commands_dict(settings, inproject):
     cmds = _get_commands_from_module('scrapy.commands', inproject)
+    cmds.update(_get_commands_from_entry_points(inproject))
     cmds_module = settings['COMMANDS_MODULE']
     if cmds_module:
         cmds.update(_get_commands_from_module(cmds_module, inproject))
@@ -48,87 +58,88 @@ def _pop_command_name(argv):
             return arg
         i += 1
 
-def _print_header(inproject):
+def _print_header(settings, inproject):
     if inproject:
-        print "Scrapy %s - project: %s\n" % (scrapy.__version__, \
-            settings['BOT_NAME'])
+        print("Scrapy %s - project: %s\n" % (scrapy.__version__, \
+            settings['BOT_NAME']))
     else:
-        print "Scrapy %s - no active project\n" % scrapy.__version__
+        print("Scrapy %s - no active project\n" % scrapy.__version__)
 
-def _print_commands(inproject):
-    _print_header(inproject)
-    print "Usage:"
-    print "  scrapy <command> [options] [args]\n"
-    print "Available commands:"
-    cmds = _get_commands_dict(inproject)
+def _print_commands(settings, inproject):
+    _print_header(settings, inproject)
+    print("Usage:")
+    print("  scrapy <command> [options] [args]\n")
+    print("Available commands:")
+    cmds = _get_commands_dict(settings, inproject)
     for cmdname, cmdclass in sorted(cmds.iteritems()):
-        print "  %-13s %s" % (cmdname, cmdclass.short_desc())
-    print
-    print 'Use "scrapy <command> -h" to see more info about a command'
-
-def _print_unknown_command(cmdname, inproject):
-    _print_header(inproject)
-    print "Unknown command: %s\n" % cmdname
-    print 'Use "scrapy" to see available commands' 
+        print("  %-13s %s" % (cmdname, cmdclass.short_desc()))
     if not inproject:
-        print
-        print "More commands are available in project mode"
+        print()
+        print("  [ more ]      More commands available when run from project directory")
+    print()
+    print('Use "scrapy <command> -h" to see more info about a command')
 
-def _check_deprecated_scrapy_ctl(argv, inproject):
-    """Check if Scrapy was called using the deprecated scrapy-ctl command and
-    warn in that case, also creating a scrapy.cfg if it doesn't exist.
-    """
-    if not any('scrapy-ctl' in x for x in argv):
-        return
-    import warnings
-    warnings.warn("`scrapy-ctl.py` command-line tool is deprecated and will be removed in Scrapy 0.11, use `scrapy` instead",
-        ScrapyDeprecationWarning, stacklevel=3)
-    if inproject:
-        projpath = os.path.abspath(os.path.dirname(os.path.dirname(settings.settings_module.__file__)))
-        cfg_path = os.path.join(projpath, 'scrapy.cfg')
-        if not os.path.exists(cfg_path):
-            with open(cfg_path, 'w') as f:
-                f.write("# generated automatically - feel free to edit" + os.linesep)
-                f.write("[settings]" + os.linesep)
-                f.write("default = %s" % settings.settings_module.__name__ + os.linesep)
+def _print_unknown_command(settings, cmdname, inproject):
+    _print_header(settings, inproject)
+    print("Unknown command: %s\n" % cmdname)
+    print('Use "scrapy" to see available commands')
 
 def _run_print_help(parser, func, *a, **kw):
     try:
         func(*a, **kw)
-    except UsageError, e:
+    except UsageError as e:
         if str(e):
             parser.error(str(e))
         if e.print_help:
             parser.print_help()
         sys.exit(2)
 
-def execute(argv=None):
+def execute(argv=None, settings=None):
     if argv is None:
         argv = sys.argv
-    crawler = CrawlerProcess(settings)
-    crawler.install()
+
+    # --- backwards compatibility for scrapy.conf.settings singleton ---
+    if settings is None and 'scrapy.conf' in sys.modules:
+        from scrapy import conf
+        if hasattr(conf, 'settings'):
+            settings = conf.settings
+    # ------------------------------------------------------------------
+
+    if settings is None:
+        settings = get_project_settings()
+    check_deprecated_settings(settings)
+
+    # --- backwards compatibility for scrapy.conf.settings singleton ---
+    import warnings
+    from scrapy.exceptions import ScrapyDeprecationWarning
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", ScrapyDeprecationWarning)
+        from scrapy import conf
+        conf.settings = settings
+    # ------------------------------------------------------------------
+
     inproject = inside_project()
-    _check_deprecated_scrapy_ctl(argv, inproject) # TODO: remove for Scrapy 0.11
-    cmds = _get_commands_dict(inproject)
+    cmds = _get_commands_dict(settings, inproject)
     cmdname = _pop_command_name(argv)
     parser = optparse.OptionParser(formatter=optparse.TitledHelpFormatter(), \
         conflict_handler='resolve')
     if not cmdname:
-        _print_commands(inproject)
+        _print_commands(settings, inproject)
         sys.exit(0)
     elif cmdname not in cmds:
-        _print_unknown_command(cmdname, inproject)
+        _print_unknown_command(settings, cmdname, inproject)
         sys.exit(2)
 
     cmd = cmds[cmdname]
     parser.usage = "scrapy %s %s" % (cmdname, cmd.syntax())
     parser.description = cmd.long_desc()
-    settings.defaults.update(cmd.default_settings)
+    settings.setdict(cmd.default_settings, priority='command')
     cmd.settings = settings
     cmd.add_options(parser)
     opts, args = parser.parse_args(args=argv[1:])
     _run_print_help(parser, cmd.process_options, args, opts)
-    cmd.set_crawler(crawler)
+
+    cmd.crawler_process = CrawlerProcess(settings)
     _run_print_help(parser, _run_command, cmd, args, opts)
     sys.exit(cmd.exitcode)
 
