@@ -1,3 +1,4 @@
+from __future__ import print_function
 from scrapy.command import ScrapyCommand
 
 class Command(ScrapyCommand):
@@ -9,5 +10,6 @@ class Command(ScrapyCommand):
         return "List available spiders"
 
     def run(self, args, opts):
-        for s in self.crawler.spiders.list():
-            print s
+        crawler = self.crawler_process.create_crawler()
+        for s in sorted(crawler.spiders.list()):
+            print(s)
