@@ -1,3 +1,4 @@
+from __future__ import print_function
 from scrapy.command import ScrapyCommand
 
 class Command(ScrapyCommand):
@@ -25,14 +26,14 @@ class Command(ScrapyCommand):
             help="print setting value, intepreted as an float")
 
     def run(self, args, opts):
-        settings = self.crawler.settings
+        settings = self.crawler_process.settings
         if opts.get:
-            print settings.get(opts.get)
+            print(settings.get(opts.get))
         elif opts.getbool:
-            print settings.getbool(opts.getbool)
+            print(settings.getbool(opts.getbool))
         elif opts.getint:
-            print settings.getint(opts.getint)
+            print(settings.getint(opts.getint))
         elif opts.getfloat:
-            print settings.getfloat(opts.getfloat)
+            print(settings.getfloat(opts.getfloat))
         elif opts.getlist:
-            print settings.getlist(opts.getlist)
+            print(settings.getlist(opts.getlist))
