@@ -4,9 +4,11 @@ Scrapy Shell
 See documentation in docs/topics/shell.rst
 """
 
+from threading import Thread
+
 from scrapy.command import ScrapyCommand
 from scrapy.shell import Shell
-from scrapy import log
+
 
 class Command(ScrapyCommand):
 
@@ -26,6 +28,8 @@ class Command(ScrapyCommand):
         ScrapyCommand.add_options(self, parser)
         parser.add_option("-c", dest="code",
             help="evaluate the code in the shell, print the result and exit")
+        parser.add_option("--spider", dest="spider",
+            help="use this spider")
 
     def update_vars(self, vars):
         """You can use this function to update the Scrapy objects that will be
@@ -34,13 +38,18 @@ class Command(ScrapyCommand):
         pass
 
     def run(self, args, opts):
+        crawler = self.crawler_process.create_crawler()
+
         url = args[0] if args else None
-        shell = Shell(self.crawler, update_vars=self.update_vars, inthread=True, \
-            code=opts.code)
-        def err(f):
-            log.err(f, "Shell error")
-            self.exitcode = 1
-        d = shell.start(url=url)
-        d.addErrback(err)
-        d.addBoth(lambda _: self.crawler.stop())
-        self.crawler.start()
+        spider = crawler.spiders.create(opts.spider) if opts.spider else None
+
+        self.crawler_process.start_crawling()
+        self._start_crawler_thread()
+
+        shell = Shell(crawler, update_vars=self.update_vars, code=opts.code)
+        shell.start(url=url, spider=spider)
+
+    def _start_crawler_thread(self):
+        t = Thread(target=self.crawler_process.start_reactor)
+        t.daemon = True
+        t.start()
