@@ -4,7 +4,7 @@ HttpError Spider Middleware
 See documentation in docs/topics/spider-middleware.rst
 """
 from scrapy.exceptions import IgnoreRequest
-
+from scrapy import log
 
 class HttpError(IgnoreRequest):
     """A non-200 response was filtered"""
@@ -16,20 +16,36 @@ class HttpError(IgnoreRequest):
 
 class HttpErrorMiddleware(object):
 
+    @classmethod
+    def from_crawler(cls, crawler):
+        return cls(crawler.settings)
+
+    def __init__(self, settings):
+        self.handle_httpstatus_all = settings.getbool('HTTPERROR_ALLOW_ALL')
+        self.handle_httpstatus_list = settings.getlist('HTTPERROR_ALLOWED_CODES')
+
     def process_spider_input(self, response, spider):
-        if 200 <= response.status < 300: # common case
+        if 200 <= response.status < 300:  # common case
             return
-        meta = response.request.meta
+        meta = response.meta
         if 'handle_httpstatus_all' in meta:
             return
         if 'handle_httpstatus_list' in meta:
             allowed_statuses = meta['handle_httpstatus_list']
+        elif self.handle_httpstatus_all:
+            return
         else:
-            allowed_statuses = getattr(spider, 'handle_httpstatus_list', ())
+            allowed_statuses = getattr(spider, 'handle_httpstatus_list', self.handle_httpstatus_list)
         if response.status in allowed_statuses:
             return
         raise HttpError(response, 'Ignoring non-200 response')
 
     def process_spider_exception(self, response, exception, spider):
         if isinstance(exception, HttpError):
+            log.msg(
+                format="Ignoring response %(response)r: HTTP status code is not handled or not allowed",
+                level=log.DEBUG,
+                spider=spider,
+                response=response
+            )
             return []
