@@ -4,6 +4,9 @@ from scrapy.utils.decorator import defers
 
 class FileDownloadHandler(object):
 
+    def __init__(self, settings):
+        pass
+
     @defers
     def download_request(self, request, spider):
         filepath = file_uri_to_path(request.url)
