@@ -11,13 +11,17 @@ spider_opened = object()
 spider_idle = object()
 spider_closed = object()
 spider_error = object()
-request_received = object()
+request_scheduled = object()
 response_received = object()
 response_downloaded = object()
 item_scraped = object()
 item_dropped = object()
-stats_spider_opened = object()
-stats_spider_closing = object()
-stats_spider_closed = object()
 
-item_passed = item_scraped # for backwards compatibility
+# for backwards compatibility
+stats_spider_opened = spider_opened
+stats_spider_closing = spider_closed
+stats_spider_closed = spider_closed
+
+item_passed = item_scraped
+
+request_received = request_scheduled
