@@ -4,7 +4,7 @@ Scheduler queues
 
 import marshal, cPickle as pickle
 
-from scrapy.utils import queue
+from queuelib import queue
 
 def _serializable_queue(queue_class, serialize, deserialize):
 
@@ -24,7 +24,7 @@ def _serializable_queue(queue_class, serialize, deserialize):
 def _pickle_serialize(obj):
     try:
         return pickle.dumps(obj, protocol=2)
-    except pickle.PicklingError, e:
+    except pickle.PicklingError as e:
         raise ValueError(str(e))
 
 PickleFifoDiskQueue = _serializable_queue(queue.FifoDiskQueue, \
