@@ -10,11 +10,8 @@ from twisted.conch import manhole, telnet
 from twisted.conch.insults import insults
 from twisted.internet import protocol
 
-from scrapy.xlib.pydispatch import dispatcher
 from scrapy.exceptions import NotConfigured
-from scrapy.stats import stats
 from scrapy import log, signals
-from scrapy.utils.signal import send_catch_log
 from scrapy.utils.trackref import print_live_refs
 from scrapy.utils.engine import print_engine_status
 from scrapy.utils.reactor import listen_tcp
@@ -37,10 +34,10 @@ class TelnetConsole(protocol.ServerFactory):
             raise NotConfigured
         self.crawler = crawler
         self.noisy = False
-        self.portrange = map(int, crawler.settings.getlist('TELNETCONSOLE_PORT'))
+        self.portrange = [int(x) for x in crawler.settings.getlist('TELNETCONSOLE_PORT')]
         self.host = crawler.settings['TELNETCONSOLE_HOST']
-        dispatcher.connect(self.start_listening, signals.engine_started)
-        dispatcher.connect(self.stop_listening, signals.engine_stopped)
+        self.crawler.signals.connect(self.start_listening, signals.engine_started)
+        self.crawler.signals.connect(self.stop_listening, signals.engine_stopped)
 
     @classmethod
     def from_crawler(cls, crawler):
@@ -49,7 +46,8 @@ class TelnetConsole(protocol.ServerFactory):
     def start_listening(self):
         self.port = listen_tcp(self.portrange, self.host, self)
         h = self.port.getHost()
-        log.msg("Telnet console listening on %s:%d" % (h.host, h.port), log.DEBUG)
+        log.msg(format="Telnet console listening on %(host)s:%(port)d",
+                level=log.DEBUG, host=h.host, port=h.port)
 
     def stop_listening(self):
         self.port.stopListening()
@@ -61,16 +59,13 @@ class TelnetConsole(protocol.ServerFactory):
 
     def _get_telnet_vars(self):
         # Note: if you add entries here also update topics/telnetconsole.rst
-        slots = self.crawler.engine.slots
-        if len(slots) == 1:
-            spider, slot = slots.items()[0]
         telnet_vars = {
             'engine': self.crawler.engine,
-            'spider': spider,
-            'slot': slot,
-            'manager': self.crawler,
+            'spider': self.crawler.engine.spider,
+            'slot': self.crawler.engine.slot,
+            'crawler': self.crawler,
             'extensions': self.crawler.extensions,
-            'stats': stats,
+            'stats': self.crawler.stats,
             'spiders': self.crawler.spiders,
             'settings': self.crawler.settings,
             'est': lambda: print_engine_status(self.crawler.engine),
@@ -78,7 +73,7 @@ class TelnetConsole(protocol.ServerFactory):
             'prefs': print_live_refs,
             'hpy': hpy,
             'help': "This is Scrapy telnet console. For more info see: " \
-                "http://doc.scrapy.org/topics/telnetconsole.html", # see #284
+                "http://doc.scrapy.org/en/latest/topics/telnetconsole.html",
         }
-        send_catch_log(update_telnet_vars, telnet_vars=telnet_vars)
+        self.crawler.signals.send_catch_log(update_telnet_vars, telnet_vars=telnet_vars)
         return telnet_vars
