@@ -2,9 +2,9 @@ import unittest
 
 from scrapy.http import Request
 from scrapy.contrib.downloadermiddleware.httpauth import HttpAuthMiddleware
-from scrapy.spider import BaseSpider
+from scrapy.spider import Spider
 
-class TestSpider(BaseSpider):
+class TestSpider(Spider):
     http_user = 'foo'
     http_pass = 'bar'
 
@@ -13,6 +13,7 @@ class HttpAuthMiddlewareTest(unittest.TestCase):
     def setUp(self):
         self.mw = HttpAuthMiddleware()
         self.spider = TestSpider('foo')
+        self.mw.spider_opened(self.spider)
 
     def tearDown(self):
         del self.mw
