@@ -1,6 +1,6 @@
 from unittest import TestCase
 
-from scrapy.spider import BaseSpider
+from scrapy.spider import Spider
 from scrapy.http import Request
 from scrapy.contrib.downloadermiddleware.useragent import UserAgentMiddleware
 from scrapy.utils.test import get_crawler
@@ -10,9 +10,9 @@ class UserAgentMiddlewareTest(TestCase):
 
     def get_spider_and_mw(self, default_useragent):
         crawler = get_crawler({'USER_AGENT': default_useragent})
-        spider = BaseSpider('foo')
+        spider = Spider('foo')
         spider.set_crawler(crawler)
-        return spider, UserAgentMiddleware()
+        return spider, UserAgentMiddleware.from_crawler(crawler)
 
     def test_default_agent(self):
         spider, mw = self.get_spider_and_mw('default_useragent')
@@ -23,29 +23,32 @@ class UserAgentMiddlewareTest(TestCase):
     def test_remove_agent(self):
         # settings UESR_AGENT to None should remove the user agent
         spider, mw = self.get_spider_and_mw('default_useragent')
-        spider.USER_AGENT = None
+        spider.user_agent = None
+        mw.spider_opened(spider)
         req = Request('http://scrapytest.org/')
         assert mw.process_request(req, spider) is None
         assert req.headers.get('User-Agent') is None
 
     def test_spider_agent(self):
         spider, mw = self.get_spider_and_mw('default_useragent')
-        spider.USER_AGENT = 'spider_useragent'
+        spider.user_agent = 'spider_useragent'
+        mw.spider_opened(spider)
         req = Request('http://scrapytest.org/')
         assert mw.process_request(req, spider) is None
         self.assertEquals(req.headers['User-Agent'], 'spider_useragent')
 
     def test_header_agent(self):
         spider, mw = self.get_spider_and_mw('default_useragent')
-        spider.USER_AGENT = 'spider_useragent'
+        spider.user_agent = 'spider_useragent'
+        mw.spider_opened(spider)
         req = Request('http://scrapytest.org/', headers={'User-Agent': 'header_useragent'})
         assert mw.process_request(req, spider) is None
         self.assertEquals(req.headers['User-Agent'], 'header_useragent')
 
     def test_no_agent(self):
         spider, mw = self.get_spider_and_mw(None)
-        spider.USER_AGENT = None
+        spider.user_agent = None
+        mw.spider_opened(spider)
         req = Request('http://scrapytest.org/')
         assert mw.process_request(req, spider) is None
         assert 'User-Agent' not in req.headers
-
