@@ -1,7 +1,8 @@
 import unittest
 
+from w3lib.encoding import resolve_encoding
 from scrapy.http import Request, Response, TextResponse, HtmlResponse, XmlResponse, Headers
-from scrapy.utils.encoding import resolve_encoding
+from scrapy.selector import Selector
 
 
 class BaseResponseTest(unittest.TestCase):
@@ -107,11 +108,17 @@ class BaseResponseTest(unittest.TestCase):
     def _assert_response_encoding(self, response, encoding):
         self.assertEqual(response.encoding, resolve_encoding(encoding))
 
+    def test_immutable_attributes(self):
+        r = self.response_class("http://example.com")
+        self.assertRaises(AttributeError, setattr, r, 'url', 'http://example2.com')
+        self.assertRaises(AttributeError, setattr, r, 'body', 'xxx')
+
+
 class ResponseText(BaseResponseTest):
 
     def test_no_unicode_url(self):
         self.assertRaises(TypeError, self.response_class, u'http://www.example.com')
-    
+
 
 class TextResponseTest(BaseResponseTest):
 
@@ -171,8 +178,8 @@ class TextResponseTest(BaseResponseTest):
         self.assertEqual(r2._headers_encoding(), None)
         self.assertEqual(r2._declared_encoding(), 'utf-8')
         self._assert_response_encoding(r2, 'utf-8')
-        self.assertEqual(r3._headers_encoding(), "iso-8859-1")
-        self.assertEqual(r3._declared_encoding(), "iso-8859-1")
+        self.assertEqual(r3._headers_encoding(), "cp1252")
+        self.assertEqual(r3._declared_encoding(), "cp1252")
         self.assertEqual(r4._headers_encoding(), None)
         self.assertEqual(r5._headers_encoding(), None)
         self._assert_response_encoding(r5, "utf-8")
@@ -188,19 +195,52 @@ class TextResponseTest(BaseResponseTest):
 
     def test_declared_encoding_invalid(self):
         """Check that unknown declared encodings are ignored"""
-        r = self.response_class("http://www.example.com", headers={"Content-type": ["text/html; charset=UKNOWN"]}, body="\xc2\xa3")
+        r = self.response_class("http://www.example.com",
+                                headers={"Content-type": ["text/html; charset=UKNOWN"]},
+                                body="\xc2\xa3")
         self.assertEqual(r._declared_encoding(), None)
         self._assert_response_values(r, 'utf-8', u"\xa3")
 
     def test_utf16(self):
         """Test utf-16 because UnicodeDammit is known to have problems with"""
-        r = self.response_class("http://www.example.com", body='\xff\xfeh\x00i\x00', encoding='utf-16')
+        r = self.response_class("http://www.example.com",
+                                body='\xff\xfeh\x00i\x00',
+                                encoding='utf-16')
         self._assert_response_values(r, 'utf-16', u"hi")
 
     def test_invalid_utf8_encoded_body_with_valid_utf8_BOM(self):
-        r6 = self.response_class("http://www.example.com", headers={"Content-type": ["text/html; charset=utf-8"]}, body="\xef\xbb\xbfWORD\xe3\xab")
+        r6 = self.response_class("http://www.example.com",
+                                 headers={"Content-type": ["text/html; charset=utf-8"]},
+                                 body="\xef\xbb\xbfWORD\xe3\xab")
         self.assertEqual(r6.encoding, 'utf-8')
-        self.assertEqual(r6.body_as_unicode(), u'\ufeffWORD\ufffd\ufffd')
+        self.assertEqual(r6.body_as_unicode(), u'WORD\ufffd\ufffd')
+
+    def test_bom_is_removed_from_body(self):
+        # Inferring encoding from body also cache decoded body as sideeffect,
+        # this test tries to ensure that calling response.encoding and
+        # response.body_as_unicode() in indistint order doesn't affect final
+        # values for encoding and decoded body.
+        url = 'http://example.com'
+        body = "\xef\xbb\xbfWORD"
+        headers = {"Content-type": ["text/html; charset=utf-8"]}
+
+        # Test response without content-type and BOM encoding
+        response = self.response_class(url, body=body)
+        self.assertEqual(response.encoding, 'utf-8')
+        self.assertEqual(response.body_as_unicode(), u'WORD')
+        response = self.response_class(url, body=body)
+        self.assertEqual(response.body_as_unicode(), u'WORD')
+        self.assertEqual(response.encoding, 'utf-8')
+
+        # Body caching sideeffect isn't triggered when encoding is declared in
+        # content-type header but BOM still need to be removed from decoded
+        # body
+        response = self.response_class(url, headers=headers, body=body)
+        self.assertEqual(response.encoding, 'utf-8')
+        self.assertEqual(response.body_as_unicode(), u'WORD')
+        response = self.response_class(url, headers=headers, body=body)
+        self.assertEqual(response.body_as_unicode(), u'WORD')
+        self.assertEqual(response.encoding, 'utf-8')
 
     def test_replace_wrong_encoding(self):
         """Test invalid chars are replaced properly"""
@@ -220,12 +260,48 @@ class TextResponseTest(BaseResponseTest):
         #r = self.response_class("http://www.example.com", body='PREFIX\xe3\xabSUFFIX')
         #assert u'\ufffd' in r.body_as_unicode(), repr(r.body_as_unicode())
 
+    def test_selector(self):
+        body = "<html><head><title>Some page</title><body></body></html>"
+        response = self.response_class("http://www.example.com", body=body)
+
+        self.assertIsInstance(response.selector, Selector)
+        self.assertEqual(response.selector.type, 'html')
+        self.assertIs(response.selector, response.selector)  # property is cached
+        self.assertIs(response.selector.response, response)
+
+        self.assertEqual(
+            response.selector.xpath("//title/text()").extract(),
+            [u'Some page']
+        )
+        self.assertEqual(
+            response.selector.css("title::text").extract(),
+            [u'Some page']
+        )
+        self.assertEqual(
+            response.selector.re("Some (.*)</title>"),
+            [u'page']
+        )
+
+    def test_selector_shortcuts(self):
+        body = "<html><head><title>Some page</title><body></body></html>"
+        response = self.response_class("http://www.example.com", body=body)
+
+        self.assertEqual(
+            response.xpath("//title/text()").extract(),
+            response.selector.xpath("//title/text()").extract(),
+        )
+        self.assertEqual(
+            response.css("title::text").extract(),
+            response.selector.css("title::text").extract(),
+        )
+
 
 class HtmlResponseTest(TextResponseTest):
 
     response_class = HtmlResponse
 
     def test_html_encoding(self):
+
         body = """<html><head><title>Some page</title><meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
         </head><body>Price: \xa3100</body></html>'
         """
@@ -256,16 +332,6 @@ class HtmlResponseTest(TextResponseTest):
         r1 = self.response_class("http://www.example.com", body=body)
         self._assert_response_values(r1, 'gb2312', body)
 
-    def test_httpequiv_meta(self):
-        body = '''<html><head><meta content="text/html; charset=gb18030" http-equiv="Content-Type" /></head></html>'''
-        response = self.response_class('http://example.com', body=body)
-        self._assert_response_values(response, 'gb18030', body)
-
-        body = '''<html><head><meta http-equiv="Content-Type" content="text/html; charset=gb18030" /></head></html>'''
-        response = self.response_class('http://example.com', body=body)
-        self._assert_response_values(response, 'gb18030', body)
-
-
 
 class XmlResponseTest(TextResponseTest):
 
@@ -299,6 +365,30 @@ class XmlResponseTest(TextResponseTest):
         self._assert_response_values(r6, 'iso-8859-1', body2)
         self._assert_response_values(r7, 'utf-8', body2)
 
+    def test_selector(self):
+        body = '<?xml version="1.0" encoding="utf-8"?><xml><elem>value</elem></xml>'
+        response = self.response_class("http://www.example.com", body=body)
+
+        self.assertIsInstance(response.selector, Selector)
+        self.assertEqual(response.selector.type, 'xml')
+        self.assertIs(response.selector, response.selector)  # property is cached
+        self.assertIs(response.selector.response, response)
+
+        self.assertEqual(
+            response.selector.xpath("//elem/text()").extract(),
+            [u'value']
+        )
+
+    def test_selector_shortcuts(self):
+        body = '<?xml version="1.0" encoding="utf-8"?><xml><elem>value</elem></xml>'
+        response = self.response_class("http://www.example.com", body=body)
+
+        self.assertEqual(
+            response.xpath("//elem/text()").extract(),
+            response.selector.xpath("//elem/text()").extract(),
+        )
+
+
 
 if __name__ == "__main__":
     unittest.main()
