@@ -1,3 +1,4 @@
+from __future__ import print_function
 from twisted.trial import unittest
 from twisted.python.failure import Failure
 from twisted.internet import reactor
@@ -5,10 +6,9 @@ from twisted.internet.defer import Deferred, inlineCallbacks
 from twisted.python import log as txlog
 
 from scrapy.http import Request, Response
-from scrapy.spider import BaseSpider
+from scrapy.spider import Spider
 from scrapy.utils.request import request_fingerprint
 from scrapy.contrib.pipeline.media import MediaPipeline
-from scrapy.utils.test import get_crawler
 from scrapy.utils.signal import disconnect_all
 from scrapy import signals
 from scrapy import log
@@ -24,16 +24,15 @@ class BaseMediaPipelineTestCase(unittest.TestCase):
     pipeline_class = MediaPipeline
 
     def setUp(self):
-        self.spider = BaseSpider('media.com')
+        self.spider = Spider('media.com')
         self.pipe = self.pipeline_class(download_func=_mocked_download_func)
         self.pipe.open_spider(self.spider)
-        self.info = self.pipe.spiderinfo[self.spider]
+        self.info = self.pipe.spiderinfo
 
     def tearDown(self):
         for name, signal in vars(signals).items():
             if not name.startswith('_'):
                 disconnect_all(signal)
-        self.pipe.close_spider(self.spider)
 
     def test_default_media_to_download(self):
         request = Request('http://url')
