@@ -1,19 +1,22 @@
 from unittest import TestCase
 
 from scrapy.http import Response, Request
-from scrapy.spider import BaseSpider
+from scrapy.spider import Spider
 from scrapy.contrib.spidermiddleware.offsite import OffsiteMiddleware
+from scrapy.utils.test import get_crawler
 
+from urlparse import urlparse
 
 class TestOffsiteMiddleware(TestCase):
 
     def setUp(self):
         self.spider = self._get_spider()
-        self.mw = OffsiteMiddleware()
+        crawler = get_crawler()
+        self.mw = OffsiteMiddleware.from_crawler(crawler)
         self.mw.spider_opened(self.spider)
 
     def _get_spider(self):
-        return BaseSpider('foo', allowed_domains=['scrapytest.org', 'scrapy.org'])
+        return Spider('foo', allowed_domains=['scrapytest.org', 'scrapy.org'])
 
     def test_process_spider_output(self):
         res = Response('http://scrapytest.org')
@@ -23,20 +26,21 @@ class TestOffsiteMiddleware(TestCase):
                        Request('http://sub.scrapy.org/1'),
                        Request('http://offsite.tld/letmepass', dont_filter=True)]
         offsite_reqs = [Request('http://scrapy2.org'),
-                       Request('http://offsite.tld/')]
+                       Request('http://offsite.tld/'),
+                       Request('http://offsite.tld/scrapytest.org'),
+                       Request('http://offsite.tld/rogue.scrapytest.org'),
+                       Request('http://rogue.scrapytest.org.haha.com'),
+                       Request('http://roguescrapytest.org')]
         reqs = onsite_reqs + offsite_reqs
 
         out = list(self.mw.process_spider_output(res, reqs, self.spider))
         self.assertEquals(out, onsite_reqs)
 
-    def tearDown(self):
-        self.mw.spider_closed(self.spider)
-
 
 class TestOffsiteMiddleware2(TestOffsiteMiddleware):
 
     def _get_spider(self):
-        return BaseSpider('foo', allowed_domains=None)
+        return Spider('foo', allowed_domains=None)
 
     def test_process_spider_output(self):
         res = Response('http://scrapytest.org')
@@ -47,5 +51,17 @@ class TestOffsiteMiddleware2(TestOffsiteMiddleware):
 class TestOffsiteMiddleware3(TestOffsiteMiddleware2):
 
     def _get_spider(self):
-        return BaseSpider('foo')
+        return Spider('foo')
 
+
+class TestOffsiteMiddleware4(TestOffsiteMiddleware3):
+
+    def _get_spider(self):
+      bad_hostname = urlparse('http:////scrapytest.org').hostname
+      return Spider('foo', allowed_domains=['scrapytest.org', None, bad_hostname])
+
+    def test_process_spider_output(self):
+      res = Response('http://scrapytest.org')
+      reqs = [Request('http://scrapytest.org/1')]
+      out = list(self.mw.process_spider_output(res, reqs, self.spider))
+      self.assertEquals(out, reqs)
