@@ -1,14 +1,14 @@
 from unittest import TestCase
 
 from scrapy.http import Response, Request
-from scrapy.spider import BaseSpider
+from scrapy.spider import Spider
 from scrapy.contrib.spidermiddleware.referer import RefererMiddleware
 
 
 class TestRefererMiddleware(TestCase):
 
     def setUp(self):
-        self.spider = BaseSpider('foo')
+        self.spider = Spider('foo')
         self.mw = RefererMiddleware()
 
     def test_process_spider_output(self):
