@@ -2,7 +2,7 @@ from unittest import TestCase
 
 from scrapy.contrib.spidermiddleware.urllength import UrlLengthMiddleware
 from scrapy.http import Response, Request
-from scrapy.spider import BaseSpider
+from scrapy.spider import Spider
 
 
 class TestUrlLengthMiddleware(TestCase):
@@ -12,10 +12,10 @@ class TestUrlLengthMiddleware(TestCase):
 
         short_url_req = Request('http://scrapytest.org/')
         long_url_req = Request('http://scrapytest.org/this_is_a_long_url')
-        reqs = [short_url_req, long_url_req] 
+        reqs = [short_url_req, long_url_req]
 
         mw = UrlLengthMiddleware(maxlength=25)
-        spider = BaseSpider('foo')
+        spider = Spider('foo')
         out = list(mw.process_spider_output(res, reqs, spider))
         self.assertEquals(out, [short_url_req])
 
