@@ -6,10 +6,7 @@ This module must not depend on any module outside the Standard Library.
 """
 
 import copy
-from collections import deque, defaultdict
-from itertools import chain
-
-from scrapy.utils.py27 import OrderedDict
+from collections import OrderedDict
 
 
 class MultiValueDictKeyError(KeyError):
@@ -46,7 +43,7 @@ class MultiValueDict(dict):
         try:
             list_ = dict.__getitem__(self, key)
         except KeyError:
-            raise MultiValueDictKeyError, "Key %r not found in %r" % (key, self)
+            raise MultiValueDictKeyError("Key %r not found in %r" % (key, self))
         try:
             return list_[-1]
         except IndexError:
@@ -59,7 +56,7 @@ class MultiValueDict(dict):
         return self.__class__(dict.items(self))
 
     def __deepcopy__(self, memo=None):
-        if memo is None: 
+        if memo is None:
             memo = {}
         result = self.__class__()
         memo[id(self)] = result
@@ -124,7 +121,7 @@ class MultiValueDict(dict):
     def update(self, *args, **kwargs):
         "update() extends rather than replaces existing key lists. Also accepts keyword args."
         if len(args) > 1:
-            raise TypeError, "update expected at most 1 arguments, got %d" % len(args)
+            raise TypeError("update expected at most 1 arguments, got %d" % len(args))
         if args:
             other_dict = args[0]
             if isinstance(other_dict, MultiValueDict):
@@ -135,7 +132,7 @@ class MultiValueDict(dict):
                     for key, value in other_dict.items():
                         self.setlistdefault(key, []).append(value)
                 except TypeError:
-                    raise ValueError, "MultiValueDict.update() takes either a MultiValueDict or dictionary"
+                    raise ValueError("MultiValueDict.update() takes either a MultiValueDict or dictionary")
         for key, value in kwargs.iteritems():
             self.setlistdefault(key, []).append(value)
 
